@@ -1,7 +1,7 @@
 
 # Compact Crypto Certs (C3) Public API
 
-__version__ = "0.9.0"
+__version__ = "0.9.4"
 
 
 from c3.constants import *
@@ -11,7 +11,7 @@ from c3 import structure
 from c3 import textfiles
 
 # quick-start APIs for verifying
-from c3.textfiles import pub_block_from_string
+from c3.textfiles import pub_block_from_string, make_pub_txt_str
 from c3.signverify import SignVerify
 
 # "note: __all__ affects the from <module> import * behavior only."
@@ -23,6 +23,7 @@ __all__ = [
 
 
 # Future todos:
-# - py2 support (b3 utf8, base64 encodebytes, more?)
+# - CSR workflow, creating a cert with --using=None
+# - py2 support (b3 utf8, base64 encodebytes, p_p pathlib2, more?)
 # - more key types e.g. libsodium
 
